<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Check if class already exists

//if (!class_exists("NNRobots_Optin_Fire_List_Table")):

/**
 * Include the WP_List_Table library
 *
 * @since 1.0.0
 *
 */
if(!class_exists('WP_List_Table')){
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}


/**
 * This class extends WP_List_Table and is used to create the table as
 *	seen in the admin panel.
 *
 * @since 1.0.0
 *
 * @extends	WP_List_Table
 */
class NNRobots_Optin_Fire_List_Table extends WP_List_Table {

	/**
	 * alternate
	 *
	 * (default value: '')
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	private static $alternate = '';

	/**
	 * text_domain
	 *
	 * (default value: 'nnrobots-optin-fire')
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	private static $text_domain = 'nnrobots-optin-fire';

	/**
	 * add_new_page
	 *
	 * (default value: "nnrobots-new-optin-fire")
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	private static $add_new_page = "nnrobots-new-optin-fire";

	/**
	 * Construtor
	 *
	 * @since 1.0.0
	 *
	 * @param	N/A
	 * @return	Instance
	 */
	function __construct(){
        global $status, $page;

        //Set parent defaults
        parent::__construct( array(
            'singular'  => 'optin',     	//singular name of the listed records
            'plural'    => 'optins',    	//plural name of the listed records
            'ajax'      => false        		//does this table support ajax?
        ) );
    }

	/**
	 * Called if there are no optin fires
	 *
	 * @since 1.0.0
	 *
	 * @param	N/A
	 * @return	N/A
	 */
	function no_items() {
		_e( 'No optin fires found.' );
	}

	/**
	 * This method dictates the table's columns and titles.
	 *
	 * @since 1.0.0
	 *
	 * @param	N/A
	 * @return	array An associative array containing column information: 'slugs'=>'Visible Titles'
	 */
	function get_columns(){
		$columns = array(
			'status'             => __( 'On/Off', NNRobots_Optin_Fire::$text_domain),
			'name'               => __( 'Name', NNRobots_Optin_Fire::$text_domain),
			//'ab'               	 => __( 'A/B Test', NNRobots_Optin_Fire::$text_domain),
			'impressions' 		 => __( 'Impressions', NNRobots_Optin_Fire::$text_domain),
			'conversions' 		 => __( 'Conversion Rate', NNRobots_Optin_Fire::$text_domain),
			'type'         		 => __( 'Type', NNRobots_Optin_Fire::$text_domain),
			'display_on'		 => __( 'Display On', NNRobots_Optin_Fire::$text_domain),
		);
		return $columns;
	}

	/**
	 * Called for any colunm without a realted function
	 *
	 * @since 1.0.0
	 *
	 * @param	array $item A singular item (one full row's worth of data)
	 * @param	array $column_name The name/slug of the column to be processed
	 * @return	string Text or HTML to be placed inside the column <td>
	 */
	function column_default( $item, $column_name ) {

		$args = NNRobots_Optin_Fire_DB::mb_unserialize($item['args']);

		switch( $column_name ) {
			default:
				return '<label>' . $item[$column_name] . '</label>';
		}
	}

	/**
	 * Custom function for the status column
	 *
	 * @since 1.0.0
	 *
	 * @param	array $item A singular item (one full row's worth of data)
	 * @return	string Text to be placed inside the column <td> (movie title only)
	 */
	function column_status($item) {

		// Check if this is a variant

		$item['args'] = NNRobots_Optin_Fire_DB::mb_unserialize($item['args']);

		// ON / OFF

		$data = '';
		$test = '';

        if ( !isset($item['args']['ab_testing']['active']) ||
        	( isset($item['args']['ab_testing']['active']) && !$item['args']['ab_testing']['active'] ) ||
			( isset($item['args']['ab_testing']['active']) && $item['args']['ab_testing']['active'] && $item['id'] == -1 ) ) {

			$id = $item['id'];

			if ($id == -1) {
				$id = $item['optin_id'];

/*
				$test = '<span class="fa-stack fa-lg">
				  <i class="fa fa-circle fa-stack-2x"></i>
				  <i class="fa fa-flag fa-stack-1x fa-inverse"></i>
				</span>';
*/
			}

			if ($item['active'] == 'Active') {

				$data = '<a data-optin-fire-id="' . $id . '" data-status="Inactive" class="' . NNRobots_Optin_Fire::$prefix_dash . 'change-status fa fa-2x fa-toggle-on" data-toggle="tooltip" data-placement="bottom" title="' . __('Deactivate', NNRobots_Optin_Fire::$text_domain) . '"></a>';

			}

			if ($item['active'] == 'Inactive') {

				$data = '<a data-optin-fire-id="' . $id . '" data-status="Active" class="' . NNRobots_Optin_Fire::$prefix_dash . 'change-status fa fa-2x fa-toggle-off" data-toggle="tooltip" data-placement="bottom" title="' . __('Activate', NNRobots_Optin_Fire::$text_domain) . '"></a>';
			}

		}

        return $data . $test;

	}

	/**
	 * Custom function for the name column
	 *
	 * @since 1.0.0
	 *
	 * @param	array $item A singular item (one full row's worth of data)
	 * @return	string Text to be placed inside the column <td> (movie title only)
	 */
	function column_name($item) {

        // Build row actions

        $actions = array();

        $item['args'] = NNRobots_Optin_Fire_DB::mb_unserialize($item['args']);

		// Play / Pause

		$play_pause = '';

		if ( !isset($item['args']['ab_testing']['active']) ||
			( isset($item['args']['ab_testing']['active']) && $item['args']['ab_testing']['active'] &&
				$item['id'] == -1 ) ) {

			if ( $item['args']['ab_testing']['on'] ) {

				$play_pause = sprintf('<a role="button" data-toggle="tooltip" data-placement="top" title="Pause Test and only show Original" data-optin-fire-id="%s" data-test-status="pause" class="pull-right btn btn-xs btn-info ' .
					NNRobots_Optin_Fire::$prefix_dash . 'change-test-status">' . __('Pause', NNRobots_Optin_Fire::$text_domain ) . ' <i class="fa fa-pause"></i></a>',
		            $item['optin_id']
		        );

/*
				$actions['edit_7'] = sprintf('<a title="Pause" data-optin-fire-id="%s" data-test-status="pause" class="' .
					NNRobots_Optin_Fire::$prefix_dash . 'change-test-status ' . NNRobots_Optin_Fire::$prefix_dash . 'row-action fa fa-pause"></a>',
		            $item['optin_id']
		        );
*/
			}

			if ( !$item['args']['ab_testing']['on'] ) {

				$play_pause = sprintf('<a role="button" title="Resume" data-optin-fire-id="%s" data-test-status="resume" class="pull-right btn btn-xs btn-info ' .
					NNRobots_Optin_Fire::$prefix_dash . 'change-test-status">' . __('Resume', NNRobots_Optin_Fire::$text_domain ) . ' <i class="fa fa-play"></i></a>',
		            $item['optin_id']
		        );
/*
				$actions['edit_7'] = sprintf('<a title="Resume" data-optin-fire-id="%s" data-test-status="resume" class="' .
					NNRobots_Optin_Fire::$prefix_dash . 'change-test-status ' . NNRobots_Optin_Fire::$prefix_dash . 'row-action fa fa-play"></a>',
		            $item['optin_id']
		        );
*/
			}

		}

		// Edit

		if ( $item['id'] == -1 ) {
			 $actions['edit_1'] = sprintf('<a title="Edit" href="?page=%s&action=edit&optin_fire_id=%s&type=test&wp_nonce=%s" class="' .
	            NNRobots_Optin_Fire::$prefix_dash . 'row-action fa fa-cogs" data-toggle="tooltip" data-placement="bottom" title="' . __('Edit', NNRobots_Optin_Fire::$text_domain) . '"></a>',
	            NNRobots_Optin_Fire::$add_new_page,
	            $item['optin_id'],
	            wp_create_nonce(NNRobots_Optin_Fire::$prefix . 'edit')
	        );
		} else {
			 $actions['edit_1'] = sprintf('<a title="Edit" href="?page=%s&action=edit&optin_fire_id=%s&wp_nonce=%s" class="' .
	            NNRobots_Optin_Fire::$prefix_dash . 'row-action fa fa-cogs" data-toggle="tooltip" data-placement="bottom" title="' . __('Edit', NNRobots_Optin_Fire::$text_domain) . '"></a>',
	            NNRobots_Optin_Fire::$add_new_page,
	            $item['id'],
	            wp_create_nonce(NNRobots_Optin_Fire::$prefix . 'edit')
	        );
		}

		// Preview

        if ( $item['id'] != -1 ) {
	    	$actions['edit_2'] = sprintf('<a title="Preview" href="?page=%s&action=preview&optin_fire_id=%s&wp_nonce=%s" class="' .
				NNRobots_Optin_Fire::$prefix_dash . 'row-action fa fa-eye" data-toggle="tooltip" data-placement="bottom" title="' . __('Preview', NNRobots_Optin_Fire::$text_domain) . '"></a>',
	            NNRobots_Optin_Fire::$dashboard_page,
	            $item['id'],
	            wp_create_nonce(NNRobots_Optin_Fire::$prefix . 'preview'));
        }

        // Duplicate / Add Variant

        if ( $item['id'] != -1 && ( !isset($item['args']['ab_testing']['active']) ||
			( isset($item['args']['ab_testing']['active']) && !$item['args']['ab_testing']['active'] ) ) ) {

			$actions['edit_3'] = sprintf('<a title="Duplicate" data-optin-fire-id="%s" class="' .
				NNRobots_Optin_Fire::$prefix_dash . 'row-action ' . NNRobots_Optin_Fire::$prefix_dash . 'duplicate fa fa-files-o" data-toggle="tooltip" data-placement="bottom" title="' . __('Duplicate', NNRobots_Optin_Fire::$text_domain) . '"></a>',
            	$item['id'],
            	wp_create_nonce(NNRobots_Optin_Fire::$prefix . 'duplicate'));

            $actions['edit_4'] = sprintf('<span data-toggle="tooltip" data-placement="bottom" title="' . __('Add Variant', NNRobots_Optin_Fire::$text_domain) . '"><a title="Add Variant" data-add="variant" data-optin-fire-id="%s" data-name="' . $item['name'] . '" data-toggle="modal" data-target="#' .
				NNRobots_Optin_Fire::$prefix_dash . 'optin-fire-add-variant" class="' .
				NNRobots_Optin_Fire::$prefix_dash . 'row-action ' . NNRobots_Optin_Fire::$prefix_dash . 'add-variant fa fa-code-fork"></a></span>',
				$item['id'],
				wp_create_nonce(NNRobots_Optin_Fire::$prefix . 'add_variant'));

		}

		// Add Variant

		if ( $item['id'] == -1 ) {
			$actions['edit_4'] = sprintf('<span data-toggle="tooltip" data-placement="bottom" title="' . __('Add Variant', NNRobots_Optin_Fire::$text_domain) . '"><a title="Add Variant" data-add="variant" data-optin-fire-id="%s" data-name="' . $item['name'] . '" data-toggle="modal" data-target="#' .
				NNRobots_Optin_Fire::$prefix_dash . 'optin-fire-add-variant" class="' .
				NNRobots_Optin_Fire::$prefix_dash . 'row-action ' . NNRobots_Optin_Fire::$prefix_dash . 'add-variant ' . NNRobots_Optin_Fire::$prefix_dash . 'parent fa fa-code-fork"></a></span>',
				$item['optin_id'],
				wp_create_nonce(NNRobots_Optin_Fire::$prefix . 'add_variant'));
		}

        // Stats

		if ( !isset($item['args']['ab_testing']['active']) ||
			( isset($item['args']['ab_testing']['active']) && !$item['args']['ab_testing']['active'] ) ||
			( isset($item['args']['ab_testing']['active']) && $item['args']['ab_testing']['active'] &&
				$item['id'] == -1 ) ) {

			$id = $item['id'];

			if ($id == -1) {
				$id = $item['optin_id'];
			}

			$actions['edit_5'] = sprintf('<a title="Stats" href="?page=%s&optin_fire_id=%s&optin_fire_name=%s" class="' .
	        	NNRobots_Optin_Fire::$prefix_dash . 'row-action fa fa-bar-chart" data-toggle="tooltip" data-placement="bottom" title="' . __('Stats', NNRobots_Optin_Fire::$text_domain) . '"></a>',
	            NNRobots_Optin_Fire::$stats_page,
	            $id,
	            $item['name']);

		}

		// End Test

		$end_test = '';

		if ( $item['id'] == -1 ) {

			$end_test = sprintf('<button type="button" title="End Test" data-optin-fire-id="%s" data-toggle="modal" class="pull-right btn btn-xs btn-info ' . NNRobots_Optin_Fire::$prefix_dash . 'end-test">%s<i style="padding-left:8px;" class="fa fa-flag-checkered"></i></button>',
	            $item['optin_id'],
	            __('End Test', NNRobots_Optin_Fire::$text_domain));
/*
			 $actions['edit_6'] = sprintf('<button type="button" title="End Test" data-optin-fire-id="%s" data-toggle="modal" class="btn btn-xs btn-info ' .
	        	NNRobots_Optin_Fire::$prefix_dash . 'row-action ' . NNRobots_Optin_Fire::$prefix_dash . 'end-test">%s<i style="padding-left:8px;" class="fa fa-flag-checkered"></i></button>',
	            $item['optin_id'],
	            __('End Test', NNRobots_Optin_Fire::$text_domain));
*/
		}

		// Delete

		if ( $item['id'] != -1 ) {
			$actions['delete'] = sprintf('<span data-toggle="tooltip" data-placement="bottom" title="' . __('Delete', NNRobots_Optin_Fire::$text_domain) . '"><a title="Delete" href="#" class="' . NNRobots_Optin_Fire::$prefix_dash . 'delete ' .
	        	NNRobots_Optin_Fire::$prefix_dash . 'row-action fa fa-trash-o" data-toggle="modal" data-target="#' . NNRobots_Optin_Fire::$prefix_dash . 'optin-fire-delete" data-name="%s" data-optin-fire-id="%s"></a></span>',
	            $item['name'],
	            $item['id']);
		}

		// Check if this is a variant

		$item['args'] = NNRobots_Optin_Fire_DB::mb_unserialize($item['args']);

		$name = '';

		if ( $item['id'] == -1 ) {

			$name = sprintf('<a title="Edit" href="?page=%s&action=edit&optin_fire_id=%s&type=test&wp_nonce=%s">%s</a>',
	            NNRobots_Optin_Fire::$add_new_page,
	            $item['optin_id'],
	            wp_create_nonce(NNRobots_Optin_Fire::$prefix . 'edit'),
	            $item['name']
	        );
		} else {

			$name = sprintf('<a title="Edit" href="?page=%s&action=edit&optin_fire_id=%s&wp_nonce=%s">%s</a>',
	            NNRobots_Optin_Fire::$add_new_page,
	            $item['id'],
	            wp_create_nonce(NNRobots_Optin_Fire::$prefix . 'edit'),
	            $item['name']
	        );
		}

		if ( $item['id'] != -1 && isset($item['args']['ab_testing']['active']) && $item['args']['ab_testing']['active'] ) {

			// Return the title contents

	        return sprintf('%1$s <small style="opacity: 0.5;">id:(%2$s) ' . ( isset($item['args']['ab_testing']['is_variant']) && !$item['args']['ab_testing']['is_variant'] ? __('Original', NNRobots_Optin_Fire::$text_domain) : '') . '</small> %3$s',
	            '<i style="padding-right:10px;" class="fa fa-code-fork"></i>' . $name,
	            $item['id'],
	            $this->row_actions($actions)
	        );
		}

        // Return the title contents

        if ( $item['id'] != -1 ) {
	        return sprintf('%1$s <small style="opacity: 0.5;">id:(%2$s)</small> %3$s',
	            '<span>' . $name . '</span>',
	            $item['id'],
	            $this->row_actions($actions)
	        );
	    } else {
		    return sprintf('%1$s %2$s',
	            '<span>' . $name . '</span> <small style="opacity: 0.5;">' . __('A/B Test', NNRobots_Optin_Fire::$text_domain) . '</small>' . $end_test . $play_pause, //<i class="fa fa-cog ' . ($item['args']['ab_testing']['on'] ? 'fa-spin' : '') . '"></i>
	            $this->row_actions($actions)
	        );
	    }
	}

	/**
	 * Custom function for the impression column
	 *
	 * @since 1.0.0
	 *
	 * @param	array $item A singular item (one full row's worth of data)
	 * @return	string Text to be placed inside the column <td> (movie title only)
	 */
	function column_impressions($item) {

		// A/B Test

		if ( $item['id'] == -1 ) {

			$total_impressions = 0;

			$stats = NNRobots_Stats_OF::getStats(null, null, $item['optin_id']);

			$impressions_total = 0;
			foreach ($stats as $stat) {
			    $impressions_total += $stat['impressions'];
			}

			$total_impressions += $impressions_total;

			// Variant stats

			if ( isset($item['args']['ab_testing']['children']) && is_array($item['args']['ab_testing']['children']) ) {
				foreach ( $item['args']['ab_testing']['children'] as $child ) {

					$stats = NNRobots_Stats_OF::getStats(null, null, $child);

					$impressions_total = 0;
					foreach ($stats as $stat) {
					    $impressions_total += $stat['impressions'];
					}

					$total_impressions += $impressions_total;
				}
			}

			return number_format($total_impressions);
		}

		$stats = NNRobots_Stats_OF::getStats(null, null, $item['id']);

		$impressions_total = 0;
		foreach ($stats as $stat) {
		    $impressions_total += $stat['impressions'];
		}

        return number_format($impressions_total);
	}

	/**
	 * Custom function for the conversions column
	 *
	 * @since 1.0.0
	 *
	 * @param	array $item A singular item (one full row's worth of data)
	 * @return	string Text to be placed inside the column <td> (movie title only)
	 */
	function column_conversions($item) {

		// A/B Test

		if ( $item['id'] == -1 ) {

			$total_impressions = 0;
			$total_conversions = 0;

			$stats = NNRobots_Stats_OF::getStats(null, null, $item['optin_id']);

			$impressions_total = 0;
			$conversions_total = 0;
			foreach ($stats as $stat) {
			    $conversions_total += $stat['conversions'];
			    $impressions_total += $stat['impressions'];
			}

			$total_impressions += $impressions_total;
			$total_conversions += $conversions_total;

			// Variant stats

			if ( isset($item['args']['ab_testing']['children']) && is_array($item['args']['ab_testing']['children']) ) {
				foreach ( $item['args']['ab_testing']['children'] as $child ) {

					$stats = NNRobots_Stats_OF::getStats(null, null, $child);

					$impressions_total = 0;
					$conversions_total = 0;
					foreach ($stats as $stat) {
					    $conversions_total += $stat['conversions'];
					    $impressions_total += $stat['impressions'];
					}

					$total_impressions += $impressions_total;
					$total_conversions += $conversions_total;
				}
			}

	        $ctr = $total_impressions != 0 ? round(($total_conversions/$total_impressions) * 100, 2) : 0;

	        return $ctr . '%';
		}

		$stats = NNRobots_Stats_OF::getStats(null, null, $item['id']);

		$impressions_total = 0;
		$conversions_total = 0;
		foreach ($stats as $stat) {
		    $conversions_total += $stat['conversions'];
		    $impressions_total += $stat['impressions'];
		}

        $ctr = $impressions_total != 0 ? round(($conversions_total/$impressions_total) * 100, 2) : 0;

        return $ctr . '%';
	}

	/**
	 * Custom function for the impressions column
	 *
	 * @since 1.0.0
	 *
	 * @param	array $item A singular item (one full row's worth of data)
	 * @return	string Text to be placed inside the column <td> (movie title only)
	 */
	function column_type($item) {

		if ( $item['id'] == -1 ) {
			return null;
		}

		switch ($item['type']) {
	        case '1':
	        	$type = __('Banner', NNRobots_Optin_Fire::$text_domain);
	        break;
	        case '2':
	        	$type = __('Popup', NNRobots_Optin_Fire::$text_domain);
	        break;
	        case '3':
	        	$type = __('Flyout', NNRobots_Optin_Fire::$text_domain);
	        break;
	        case '4':
	        	$type = __('In Post Content', NNRobots_Optin_Fire::$text_domain);
	        break;
	        case '5':
	        	$type = __('Widget', NNRobots_Optin_Fire::$text_domain);
	        break;
	        default:
				$type = __('Banner', NNRobots_Optin_Fire::$text_domain);
	        break;
	    }

		return $type;
	}

	/**
	 * Custom function for the name column
	 *
	 * @since 1.0.0
	 *
	 * @param	array $item A singular item (one full row's worth of data)
	 * @return	string Text to be placed inside the column <td> (movie title only)
	 */
	function column_display_on($item) {

        $trigger = NNRobots_Optin_Fire_DB::mb_unserialize($item['trigger']);
        $args = NNRobots_Optin_Fire_DB::mb_unserialize($item['args']);

        $display_on = '';

        // Check for all variants and the original

        if (  $item['id'] != -1 && isset($args['ab_testing']['active']) && $args['ab_testing']['active'] ) {
			return '';
		}

        switch ($trigger['display_on']) {
	        case 'site':
	        	$display_on = __('Site Wide', NNRobots_Optin_Fire::$text_domain);
	        break;

	        case 'frontpage':
	        	$display_on .= '<a href="' . get_home_url() . '" target="_blank">' . __('Front Page', NNRobots_Optin_Fire::$text_domain) . '</a>';
	        break;

	        case 'archive':

				$display_on .= __('Archive Pages', NNRobots_Optin_Fire::$text_domain);

	        break;

	        case 'tag':

	        	$display_on .= __('Tags:', NNRobots_Optin_Fire::$text_domain) . ' <br/>';

	        	$tags = get_tags(array('include' => $trigger['tag']['id']));

	        	foreach ($tags as $tag) {
		        	$display_on .= '<a href="' . get_tag_link($tag->term_id) . '" target="_blank">' . $tag->name . '</a><br/>';
	        	}

	        break;

	        case 'category':

	        	if ($trigger['category']['all']) {
					$display_on .= __('Category Archives', NNRobots_Optin_Fire::$text_domain);
	        	} else {

		        	$display_on .= __('Categories:', NNRobots_Optin_Fire::$text_domain) . ' <br/>';

		        	$categories = get_categories(array('include' => $trigger['category']['id']));

		        	foreach ($categories as $category) {
			        	$display_on .= '<a href="' . get_category_link($category->term_id) . '" target="_blank">' . $category->name . '</a><br/>';
		        	}
	        	}

	        break;

	        default:

				if ($trigger[$trigger['display_on']]['all']) {
					$display_on .= __('All', NNRobots_Optin_Fire::$text_domain) . ' ' . ucfirst($trigger['display_on'] . 's');
				} else {

					//$display_on .= ucfirst($trigger['display_on']) . 's: <br/>';
					$display_on_post = '<ul style="padding-left: 20px;list-style-type: disc;">';

					if ($trigger[$trigger['display_on']]['id'] != '') {
						$posts = get_posts(array(
							'post_type'	=> $trigger['display_on'],
							'include' 	=> $trigger[$trigger['display_on']]['id']
						));

			        	foreach ($posts as $post) {
				        	$display_on_post .= '<li><a href="' . get_permalink($post->ID) . '" target="_blank">' . $post->post_title . '</a></li>';
			        	}
					}

					$display_on_post .= '</ul>';

 					$display_on .= '<a role="button" type="button" data-toggle="modal" data-target="#' . $item['id'] . '-' . $trigger['display_on'] . '">' . __('Certain ', NNRobots_Optin_Fire::$text_domain) . ucfirst($trigger['display_on']) . 's</a><div class="modal fade" id="' . $item['id'] . '-' . $trigger['display_on'] . '" tabindex="-1" role="dialog"><div class="modal-dialog" style="width: 400px;"><div class="modal-content"><div class="modal-header"><button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button><h4 class="modal-title">' . ucfirst($trigger['display_on']) . 's</h4></div><div class="modal-body">' . $display_on_post . '</div><div class="modal-footer"><button type="button" class="btn btn-default" data-dismiss="modal">Close</button></div></div></div></div>';

				}

	        break;
        }

        if ( isset($args['placement']['type']) && $args['placement']['type'] == 'none') {
			$display_on = __('Shortcode or Widget', NNRobots_Optin_Fire::$text_domain);
        }

        if ( isset($trigger['manual_display']) && $trigger['manual_display'] == 'yes') {
			$display_on = __('Display Manually', NNRobots_Optin_Fire::$text_domain);
        }

        return rtrim($display_on, '<br/>');
	}

	/**
	 * Prepares data for display.
	 *
	 * @since 1.0.0
	 *
	 * @param	N/A
	 * @return	N/A
	 */
	function prepare_items() {
		global $wpdb;

        $per_page = 50;

        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();

        $this->_column_headers = array($columns, $hidden, $sortable);

        //$this->process_bulk_action();

        $orderby = (!empty($_REQUEST['orderby'])) ? $_REQUEST['orderby'] : 'id';
        $order = (!empty($_REQUEST['order'])) ? $_REQUEST['order'] : 'asc';

        $active = '';

        if ( isset($_GET['status']) && $_GET['status'] == 'active' ) {
	        $active = "WHERE `active` = 'Active'";
        }

        else if ( isset($_GET['status']) && $_GET['status'] == 'inactive' ) {
	        $active = "WHERE `active` = 'Inactive'";
        }

		$data = $wpdb->get_results($wpdb->prepare("SELECT * FROM `" . NNRobots_Optin_Fire_DB::getTableName() . "` " . $active . " ORDER BY %s %s;", $orderby, $order ),'ARRAY_A');

		// Order optin fires to have A/B Testing optin fires next to each other

		$optins = array();

		foreach ( $data as $optin ) {

			$args = NNRobots_Optin_Fire_DB::mb_unserialize($optin['args']);

			// Add variants to optin list

			if ( isset($args['ab_testing']['active']) &&
				 $args['ab_testing']['active'] &&
				 !$args['ab_testing']['is_variant'] ) {

				// Add parent optin

				$test_optin = $optin;

				$test_optin['id'] = -1;
				$test_optin['optin_id'] = $optin['id'];
				$test_optin['name'] = $args['ab_testing']['name'];

				$optins[] = $test_optin;
				$optins[] = $optin;

				if ( is_array($args['ab_testing']['children']) ) {
					foreach ( $args['ab_testing']['children'] as $child ) {
						foreach ( $data as $val ) {
							if ($val['id'] == $child) {
								$optins[] = $val;
							}
						}
					}
				}
			}

			// Add all optins that are not in a test

			else if ( !isset($args['ab_testing']['active']) ||
					( isset($args['ab_testing']['active']) && !$args['ab_testing']['active'] ) ) {

				$optins[] = $optin;
			}

		}

        $current_page = $this->get_pagenum();

        $total_items = count($optins);

        /**
         * The WP_List_Table class does not handle pagination for us, so we need
         * to ensure that the data is trimmed to only the current page. We can use
         * array_slice() to
         */
        $data = array_slice($optins,(($current_page-1)*$per_page),$per_page);

        $this->items = $optins;

        $this->set_pagination_args( array(
            'total_items' => $total_items,                  //WE have to calculate the total number of items
            'per_page'    => $per_page,                     //WE have to determine how many items to show on a page
            'total_pages' => ceil($total_items/$per_page)   //WE have to calculate the total number of pages
        ) );
	}

	/**
	 * Get a list of CSS classes for the <table> tag
	 *
	 * @since 3.1.0
	 * @access protected
	 *
	 * @return array
	 */
	public function get_table_classes() {
	    return array('table table-responsive');
	}

	/**
	 * Display the table
	 *
	 * @since 3.1.0
	 * @access public
	 */
	public function display() {
		$singular = $this->_args['singular'];

		//$this->display_tablenav( 'top' );

		?>
		<table class="<?php echo implode( ' ', $this->get_table_classes() ); ?>">
			<thead>
			<tr>
				<?php $this->print_column_headers(); ?>
			</tr>
			</thead>

			<tbody id="the-list"<?php
				if ( $singular ) {
					echo " data-wp-lists='list:$singular'";
				} ?>>
				<?php $this->display_rows_or_placeholder(); ?>
			</tbody>
		</table>
		<?php
		$this->display_tablenav( 'bottom' );
	}

	/**
	 * Generates content for a single row of the table
     *
     * @since 3.1.0
     * @access public
     *
     * @param object $item The current item
     */

    public function single_row( $item ) {

		// Check if this is a variant

		$item['args'] = NNRobots_Optin_Fire_DB::mb_unserialize($item['args']);

		$class = '';

		// Active

		if ( $item['active'] == 'Active' && ( !isset($item['args']['ab_testing']['active']) || ( isset($item['args']['ab_testing']['active']) && !$item['args']['ab_testing']['active'] ) )) {

			$class = NNRobots_Optin_Fire::$prefix_dash . 'active-row';

		}

		// Test

		else if ( $item['active'] == 'Active' && isset($item['args']['ab_testing']['active']) && $item['args']['ab_testing']['active'] ) {

			$class = NNRobots_Optin_Fire::$prefix_dash . 'test-row';

		}

		// Inactive

		else {

			$class = NNRobots_Optin_Fire::$prefix_dash . 'inactive-row';

		}

		$data_type = 'data-type="' . $item['type'] . '" data-name="' . $item['name'] . '"';

		if ( isset($item['args']['ab_testing']['active']) && $item['args']['ab_testing']['active'] &&
			 isset($item['args']['ab_testing']['is_variant']) && $item['args']['ab_testing']['is_variant'] ) {

			$data_type .= ' data-variant="yes" data-optin-fire-id="' . $item['id'] . '"';

		} else if ( $item['id'] != -1 && isset($item['args']['ab_testing']['active']) && $item['args']['ab_testing']['active'] &&
			 isset($item['args']['ab_testing']['is_variant']) && !$item['args']['ab_testing']['is_variant'] ) {

			$data_type .= ' data-variant="no" data-optin-fire-id="' . $item['id'] . '"';

		} else if ( $item['id'] == -1 && isset($item['args']['ab_testing']['active']) && $item['args']['ab_testing']['active'] &&
			 isset($item['args']['ab_testing']['is_variant']) && !$item['args']['ab_testing']['is_variant'] ) {

			$data_type .= ' data-optin-test-id="' . $item['optin_id'] . '"';

		} else {

			$data_type .= ' data-optin-fire-id="' . $item['id'] . '"';
		}

		 // Alternate

	    if ( !isset($item['args']['ab_testing']['active']) || ( isset($item['args']['ab_testing']['active']) && !$item['args']['ab_testing']['active'] ) || $item['id'] == -1 ) {

			if ( self::$alternate == '' ) {
				self::$alternate = 'alternate';
			} else {
				self::$alternate = '';
			}
		}

		echo '<tr class="' . $class . ' ' . self::$alternate . '" ' . $data_type . '>';
		$this->single_row_columns( $item );
		echo '</tr>';
	}

	/**
	 * Generate row actions div
	 *
	 * @since 3.1.0
	 * @access protected
	 *
	 * @param array $actions The list of actions
	 * @param bool $always_visible Whether the actions should be always visible
	 * @return string
	 */
	protected function row_actions( $actions, $always_visible = false ) {

		$action_count = count( $actions );
		$i = 0;

		if ( !$action_count )
			return '';

		$out = '<div class="' . ( $always_visible ? 'row-actions visible' : 'row-actions' ) . '">';
		foreach ( $actions as $action => $link ) {
			++$i;
			( $i == $action_count ) ? $sep = '' : $sep = ' | ';
			$out .= "<span class='$action'>$link$sep</span>";
		}
		$out .= '</div>';

		return $out;
	}

	/**
	 * Generates and display row actions links for the list table.
	 *
	 * @since 4.3.0
	 * @access protected
	 *
	 * @param object $item        The item being acted upon.
	 * @param string $column_name Current column name.
	 * @param string $primary     Primary column name.
	 * @return string The row actions output. In this case, an empty string.
	 */
	protected function handle_row_actions( $item, $column_name, $primary ) {
		return '';
 	}
}

//endif;
?>