<?php

// Check if class already exists

//if (!class_exists("NNRobots_Email_Entries_OF")):

// AJAX functions for contact form

add_action( 'wp_ajax_nnr_of_send_email', 			array('NNRobots_Email_Entries_OF', 'sendEmail'));
add_action( 'wp_ajax_nopriv_nnr_of_send_email', 	array('NNRobots_Email_Entries_OF', 'sendEmail'));

/**
 * NNRobots_Email_Entries_OF class.
 *
 * This class is used to record all stats for optins.
 */
class NNRobots_Email_Entries_OF {

	/**
	 * table_name
	 *
	 * (default value: 'nnrobots_optin_fire_entries')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	public static $table_name = 'nnrobots_optin_fire_entries';

	/**
	 * Create Table when this class is loaded
	 *
	 * @access public
	 * @return void
	 */
	function __construct() {
		self::createTable();
	}

	/**
	 * Creates the Stats table if it does not exist
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function createTable(){

		global $wpdb;

		$wpdb->query("
			CREATE TABLE IF NOT EXISTS " . self::getTableName() . " (
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`date` datetime NOT NULL,
				`optin_fire_id` int(11) NOT NULL,
				`email` varchar(255) NOT NULL DEFAULT '',
				`subject` varchar(100) NOT NULL DEFAULT '',
				`message` longtext NOT NULL DEFAULT '',
				PRIMARY KEY (`id`)
			) ENGINE=InnoDB DEFAULT CHARSET=latin1 AUTO_INCREMENT=1;
		");

	}

	/**
	 * Get the entries over a date range in all time
	 *
	 * @access public
	 * @static
	 * @param mixed $start
	 * @param mixed $end
	 * @param mixed $id (default: null)
	 * @return void
	 */
	static function getEntries($start, $end, $email = null, $select = '*') {

		// Safey to make sure the table is there

		self::createTable();

		$query = null;

		global $wpdb;

		// All Optins, All Time

		if ($start == null && $end == null && $email == null) {
			$query = 'SELECT ' . $select . ' FROM ' . self::getTableName();
		}

		// All Optins, After Date

		else if ($start != null && $end == null && $email == null) {
			$query = $wpdb->prepare('SELECT ' . $select . ' FROM ' . self::getTableName() . ' WHERE `date` = %s', $start);
		}

		// All Optins, Date Range

		else if ($start != null && $end != null && $email == null) {
			$query = $wpdb->prepare('SELECT ' . $select . ' FROM ' . self::getTableName() . ' WHERE `date` >= %s AND `date` <= %s', $start, $end);
		}

		// Single Email

		else if ($start == null && $end == null && $email != null) {
			$query = $wpdb->prepare('SELECT ' . $select . ' FROM ' . self::getTableName() . ' WHERE `email` = %d', $email);
		}

		// No query was created

		if (!isset($query)) {
			return false;
		}

		$result = $wpdb->get_results($query, 'ARRAY_A');

		return $result;
	}

	/**
	 * Get entry data from Entry ID
	 *
	 * @access public
	 * @static
	 * @param mixed $entry_id (default: null)
	 * @return void
	 */
	static function getEntry($entry_id = null) {

		// Check if entry ID was given

		if (!isset($entry_id)) {
			return false;
		}

		global $wpdb;

		$query = $wpdb->prepare('SELECT * FROM ' . self::getTableName() . ' WHERE `id` = %d', $entry_id);

		// No query was created

		if (!isset($query)) {
			return false;
		}

		$result = $wpdb->get_results($query, 'ARRAY_A');

		return $result;
	}

	/**
	 * Send Email from Contact Form
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function sendEmail() {

		// Could not find Optin ID

		if (!isset($_POST['optin_fire_id']) || $_POST['optin_fire_id'] == '') {
			echo json_encode(array(
				'id'		=> $_POST['optin_fire_id'],
				'status'	=> 'warning',
				'message'	=> 'Could not find Optin ID.'
			));
			die();
		}

		// No Sender email

		if (!isset($_POST['send']) || $_POST['send'] == '') {
			echo json_encode(array(
				'id'		=> $_POST['optin_fire_id'],
				'status'	=> 'warning',
				'message'	=> 'No sender email address provided.'
			));
			die();
		}

		// No Email

		if (!isset($_POST['email']) || $_POST['email'] == '') {
			echo json_encode(array(
				'id'		=> $_POST['optin_fire_id'],
				'status'	=> 'warning',
				'message'	=> 'No Email address provided.'
			));
			die();
		}

		// Invalid Email Address

		if (!filter_var($_POST['email'], FILTER_VALIDATE_EMAIL)) {
			echo json_encode(array(
				'id'		=> $_POST['optin_fire_id'],
				'status'	=> 'warning',
				'message'	=> 'Invalid Email provided.'
			));
			die();
		}

		// No Subject

		if (!isset($_POST['subject']) || $_POST['subject'] == '') {
			echo json_encode(array(
				'id'		=> $_POST['optin_fire_id'],
				'status'	=> 'warning',
				'message'	=> 'Please add a subject.'
			));
			die();
		}

		// No Message

		if (!isset($_POST['message']) || $_POST['message'] == '') {
			echo json_encode(array(
				'id'		=> $_POST['optin_fire_id'],
				'status'	=> 'warning',
				'message'	=> 'Please add a messsage.'
			));
			die();
		}

		$sanitized_send = explode(',', $_POST['send']);
		$sanitized_email = stripcslashes(sanitize_email($_POST['email']));
		$sanitized_message = stripcslashes(sanitize_text_field($_POST['message']));
		$sanitized_subject = stripcslashes(sanitize_text_field($_POST['subject']));

		$message = $sanitized_message . "\r\n\r\n This message was delivered from one of your Optins.  To contact back please email " . $sanitized_email;
		$headers[] = 'From: ' . $sanitized_email;
		$result = wp_mail($sanitized_send, $sanitized_subject, $message, $headers);

		if ($result) {

			include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . 'admin/model/db.php');

			$nnrobots_optin_fire_db = new NNRobots_Optin_Fire_DB();
			$optin_fire = $nnrobots_optin_fire_db->get_data_from_id($_POST['optin_fire_id']);

			$success_action = stripcslashes($optin_fire['news_letter']['success_action']);
			$success_mesage = stripcslashes($optin_fire['news_letter']['success_message']);
			$success_url 	= stripcslashes($optin_fire['news_letter']['success_url']);

			self::createTable();

			echo json_encode(array(
				'id'			=> $_POST['optin_fire_id'],
				'status'		=> 'check',
				'message'		=> htmlentities($optin_fire['template']['args']['contact_us']['thank_you']),
				'conversion'	=> self::recordConversion($_POST['optin_fire_id']),
				'entry'			=> self::addEntry($_POST['optin_fire_id'], $sanitized_email, $sanitized_subject, $sanitized_message)
			));

		} else {
			echo json_encode(array(
				'id'		=> $_POST['optin_fire_id'],
				'status'	=> 'check',
				'message'	=> 'Message could not be sent.'
			));
		}

		die(); // this is required to terminate immediately and return a proper response

	}

	/**
	 * Add an entry once user sends email made by a optin
	 *
	 * @access public
	 * @static
	 * @param mixed $id (default: null)
	 * @param mixed $email (default: null)
	 * @param mixed $subject (default: null)
	 * @param mixed $message (default: null)
	 * @return void
	 */
	static function addEntry($id = null, $email = null, $subject = null, $message = null) {

		// No Email

		if (!isset($email) || $email == '') {
			return;
		}

		// Invalid Email Address

		if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
			return;
		}

		// No subject

		if (!isset($subject)) {
			return;
		}

		// No message

		if (!isset($message)) {
			return;
		}

		// Could not find Optin ID

		if (!isset($id) || $id == '') {
			return;
		}

		global $wpdb;
		$today = date(NNROBOTS_OPTIN_FIRE_ENTRY_DATE_FORMAT);

		$query = $wpdb->prepare('INSERT INTO ' . self::getTableName() . ' (
			`date`,
			`optin_fire_id`,
			`email`,
			`subject`,
			`message`
			) VALUES (%s, %d, %s, %s, %s)',
			$today,
			$id,
			$email,
			$subject,
			$message
		);

		$result = $wpdb->query($query);

		if ($result) {
			return 'Your email has been sent!';
		} else {
			return 'We were unable to send your email.';
		}

		return null;
	}

	/**
	 * Record a converison made by a newsletter signup
	 *
	 * @access public
	 * @static
	 * @param mixed $optin_fire_id
	 * @return void
	 */
	static function recordConversion($optin_fire_id) {

		include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . 'core/model/stats.php');

		// Return if no data is given

		if (!isset($optin_fire_id)) {
			return 'Optin conversion was NOT able to be recored because the Optin ID was not retrieved.';
		}

		// Return if user is admin or higher

		if (current_user_can('edit_published_posts')) {
			return 'Optin conversion was NOT able to be recored because current user is not authorized to log conversions.';
		}

		// Return false if crawler

		if (NNRobots_Stats_OF::isBot()) {
			return 'Optin conversion was NOT able to be recored because there is no user.  A crawler was detected.';
		}

		global $wpdb;
		$today = date(NNROBOTS_OPTIN_FIRE_DATE_FORMAT);

		// Check if entry already exsits

		$query = $wpdb->prepare('SELECT * FROM ' . NNRobots_Stats_OF::getTableName() . ' WHERE `date` = %s AND `optin_fire_id` = %d', $today, $optin_fire_id);
		$optin_fire_conversions = $wpdb->query($query);

		// Entry aleady exists, just add 1

		if (isset($optin_fire_conversions) && $optin_fire_conversions != 0) {

			$query = $wpdb->prepare('UPDATE ' . NNRobots_Stats_OF::getTableName() . ' SET
				`conversions` = `conversions` + 1
				WHERE `date` = %s AND `optin_fire_id` = %d', $today, $optin_fire_id);

			$result = $wpdb->query($query);

		}

		// Entry does not exist, create a new one and set impressions to 1

		else {
			$query = $wpdb->prepare('INSERT INTO ' . NNRobots_Stats_OF::getTableName() . ' (
				`date`,
				`optin_fire_id`,
				`impressions`,
				`conversions`
				) VALUES (%s, %d, 0, 1)',
				$today,
				$optin_fire_id
			);

			$result = $wpdb->query($query);
		}

		if ($result) {
			return 'Optin conversion was able to be recored.';
		} else {
			return 'Optin conversion was NOT able to be recored.';
		}

		return '';
	}

	/**
	 * Deletes the stats for a optin when the optin is deleted
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function deleteEntry($id) {

		// Return false if optin_fire_id is not set

		if (!isset($id)) {
			return false;
		}

		global $wpdb;

		// Check if entry already exsits

		$query = $wpdb->prepare('DELETE FROM ' . self::getTableName() . ' WHERE `id` = %d', $id);
		$result = $wpdb->query($query);

		return $result;

	}

	/**
	 * Returns the proper table name based off of site ID
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function getTableName(){

		global $wpdb;

		return '`' . $wpdb->prefix . self::$table_name . '`';
	}

}

//endif;